==> verifyica-api-0.1.0-sources.jar: org/verifyica/api/ArgumentContext.java <==
/*
 * Copyright (C) 2024 The Verifyica project authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.verifyica.api;

/** Interface to implement ArgumentContext */
public interface ArgumentContext extends Context {

    /**
     * Get the EngineContext
     *
     * <p>Equivalent to getClassContext().getEngineContext()
     *
     * @return the Engine Configuration
     */
    default EngineContext getEngineContext() {
        return getClassContext().getEngineContext();
    }

    /**
     * Get the ClassContext
     *
     * @return the ClassContext
     */
    ClassContext getClassContext();

    /**
     * Get the Argument index
     *
     * @return the Argument index
     */
    int getTestArgumentIndex();

    /**
     * Get the Argument
     *
     * @return the Argument
     */
    Argument<?> getTestArgument();

    /**
     * Get the Argument
     *
     * @param type type
     * @return the Argument
     * @param <V> type
     */
    <V> Argument<V> getTestArgument(Class<V> type);
}

==> verifyica-api-0.2.3-sources.jar: org/verifyica/api/ArgumentContext.java <==
/*
 * Copyright (C) 2024 The Verifyica project authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.verifyica.api;

/** Interface to implement ArgumentContext */
public interface ArgumentContext extends Context {

    /**
     * Get the EngineContext
     *
     * <p>Equivalent to getClassContext().getEngineContext()
     *
     * @return the Engine Configuration
     */
    EngineContext engineContext();

    /**
     * Get the ClassContext
     *
     * @return the ClassContext
     */
    ClassContext classContext();

    /**
     * Get the Argument index
     *
     * @return the Argument index
     */
    int testArgumentIndex();

    /**
     * Get the Argument
     *
     * @return the Argument
     */
    Argument<?> testArgument();

    /**
     * Get the Argument
     *
     * @param type type
     * @return the Argument
     * @param <V> type
     */
    <V> Argument<V> testArgument(Class<V> type);

    /**
     * Get the Argument payload
     *
     * @return the Argument payload
     * @param <V> type
     */
    <V> V testArgumentPayload();

    /**
     * Get the Argument
     *
     * @param type type
     * @return the Argument
     * @param <V> type
     */
    <V> V testArgumentPayload(Class<V> type);

    /**
     * Get the EngineContext
     *
     * <p>Equivalent to getClassContext().getEngineContext()
     *
     * @return the Engine Configuration
     */
    default EngineContext getEngineContext() {
        return getClassContext().getEngineContext();
    }

    /**
     * Get the ClassContext
     *
     * @return the ClassContext
     */
    ClassContext getClassContext();

    /**
     * Get the Argument index
     *
     * @return the Argument index
     */
    int getTestArgumentIndex();

    /**
     * Get the Argument
     *
     * @return the Argument
     */
    Argument<?> getTestArgument();

    /**
     * Get the Argument
     *
     * @param type type
     * @return the Argument
     * @param <V> type
     */
    <V> Argument<V> getTestArgument(Class<V> type);

    /**
     * Get the Argument payload
     *
     * @return the Argument payload
     * @param <V> type
     */
    <V> V getTestArgumentPayload();

    /**
     * Get the Argument payload
     *
     * @param type type
     * @return the Argument payload
     * @param <V> type
     */
    <V> V getTestArgumentPayload(Class<V> type);
}
